# -*- coding: utf-8 -*-
#
# Copyright (C) 2016 Gauvain Pocentek <gauvain@pocentek.net>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

GUEST_ACCESS = 10
REPORTER_ACCESS = 20
DEVELOPER_ACCESS = 30
MASTER_ACCESS = 40
OWNER_ACCESS = 50

VISIBILITY_PRIVATE = 0
VISIBILITY_INTERNAL = 10
VISIBILITY_PUBLIC = 20

NOTIFICATION_LEVEL_DISABLED = 'disabled'
NOTIFICATION_LEVEL_PARTICIPATING = 'participating'
NOTIFICATION_LEVEL_WATCH = 'watch'
NOTIFICATION_LEVEL_GLOBAL = 'global'
NOTIFICATION_LEVEL_MENTION = 'mention'
NOTIFICATION_LEVEL_CUSTOM = 'custom'
